from liquer import *
from liquer.context import Context
from pathlib import Path
from liquer.store import web_mount_folder, get_store, get_web_store

def assets_path():
    return str((Path(__file__).parent/"assets").resolve())

def init():
    web_mount_folder("gui", assets_path())





import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="liquer-gui",
    version="0.1.4",
    author="Orest Dubay",
    author_email="orest3.dubay@gmail.com",
    description="""LiQuer GUI - user interface for LiQuer.""",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/orest-d/liquer-gui",
    packages=setuptools.find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=['Flask', 'liquer-framework'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
